@@ -2,8 +2,8 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-26 15:26:32
-:LastEditTime: 2021-04-27 11:16:38
-:LastEditors: HuangJingCan
+@LastEditTime: 2021-12-09 09:58:40
+@LastEditors: HuangJianYi
 :Description: 活动处理
 """
 from seven_cloudapp.handlers.seven_base import *
@@ -229,4 +229,139 @@ class PrizeListHandler(SevenBaseHandler):
         result_info["key_id"] = key_id
         result_info["prize_list"] = act_prize_result_list
 
+        return self.reponse_json_success(result_info)
+
+
+class MinboxListHandler(SevenBaseHandler):
+    """
+    :description: 小盒子奖品列表
+    """
+    @filter_check_params("act_id")
+    def get_async(self):
+        """
+        :description: 小盒子奖品列表
+        :param act_id:活动id
+        :param machine_id:机台id
+        :param ver:版本
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_taobao_param().source_app_id
+        open_id = self.get_taobao_param().open_id
+        act_id = int(self.get_param("act_id", "0"))
+        machine_id = int(self.get_param("machine_id", "0"))
+        #self.logging_link_info("分配的奖品列表1111-" + str(self.request_params))
+
+        #请求太频繁限制
+        if self.check_post(f"PrizeList_Post_{str(open_id)}_{str(machine_id)}") == False:
+            return self.reponse_json_error("HintMessage", "对不起，请求太频繁")
+
+        #入队列
+        queue_name = f"PrizeList_Queue_{str(machine_id)}"
+        identifier = None
+        is_lock = False
+        if self.check_lpush(queue_name, open_id) == False:
+            identifier = self.acquire_lock(queue_name)
+            is_lock = True
+        if isinstance(identifier, bool):
+            return self.reponse_json_error("UserLimit", "当前人数过多,请稍后再来")
+
+        machine_info_model = MachineInfoModel(context=self)
+        act_prize_model = ActPrizeModel(context=self)
+        surplus_queue_model = SurplusQueueModel(context=self)
+        machine_info = machine_info_model.get_entity_by_id(machine_id)
+        if not machine_info or machine_info.is_release == 0:
+            self.lpop(queue_name)
+            self.release_lock(queue_name, identifier)
+            return self.reponse_json_error("NoMachine", "对不起，找不到该盲盒")
+        specs_type = machine_info.specs_type
+        if specs_type == 5:
+            ran_num = random.randint(3, 5)
+        elif specs_type == 6:
+            ran_num = random.randint(3, 6)
+        elif specs_type == 7:
+            ran_num = random.randint(3, 7)
+        elif specs_type == 8:
+            ran_num = random.randint(4, 8)
+        elif specs_type == 9:
+            ran_num = random.randint(5, 9)
+        elif specs_type == 10:
+            ran_num = random.randint(6, 10)
+        elif specs_type == 12:
+            ran_num = random.randint(7, 12)
+        else:
+            ran_num = random.randint(9, 16)
+
+        condition = "act_id=%s AND machine_id=%s AND is_release=1 AND surplus>0 AND probability>0"
+        act_prize_list = act_prize_model.get_list(condition, params=[act_id, machine_id])
+        if len(act_prize_list) <= 0:
+            self.lpop(queue_name)
+            if is_lock:
+                self.release_lock(queue_name, identifier)
+            return self.reponse_json_error("NoPrize", "对不起，该盲盒已售罄")
+        if ran_num > len(act_prize_list):
+            ran_num = len(act_prize_list)
+        act_prize_id_list = []
+        random_Prize_dict_list = {}
+        for act_prize in act_prize_list:
+            random_Prize_dict_list[act_prize.id] = act_prize.probability
+        for i in range(ran_num):
+            prize_id = self.random_weight(random_Prize_dict_list)
+            act_prize_id_list.append(prize_id)
+            if machine_info.is_repeat_prize == 0:
+                del random_Prize_dict_list[prize_id]
+        act_prize_process_list = []
+        if len(act_prize_id_list) > 0:
+            if machine_info.is_repeat_prize == 0:
+                act_prize_process_list = [act_prize for act_prize in act_prize_list if act_prize.id in act_prize_id_list]
+            else:
+                for prize_id in act_prize_id_list:
+                    filter_act_prize = [act_prize for act_prize in act_prize_list if act_prize.id == prize_id]
+                    if len(filter_act_prize) > 0:
+                        act_prize_process_list.extend(filter_act_prize)
+        else:
+            self.lpop(queue_name)
+            if is_lock:
+                self.release_lock(queue_name, identifier)
+            return self.reponse_json_error("NoPrize", "对不起，该盲盒已售罄")
+
+        key_id = self.create_order_id()
+        result_info = {}
+        result_list = []
+        redis_prize_dict = {}
+        serial_no = 0
+        for act_prize in act_prize_process_list:
+            update_result = act_prize_model.update_table("surplus=surplus-1", "id=%s AND surplus>0", params=[act_prize.id])
+            # self.logging_link_info("update_result-" + str(update_result) + str(act_prize.id))
+            if update_result == True:
+                serial_no = int(serial_no) + 1
+                #预扣队列
+                surplus_queue = SurplusQueue()
+                surplus_queue.app_id = app_id
+                surplus_queue.act_id = act_id
+                surplus_queue.machine_id = machine_id
+                surplus_queue.prize_id = act_prize.id
+                surplus_queue.key_id = key_id
+                surplus_queue.open_id = open_id
+                surplus_queue.withhold_value = 1
+                surplus_queue.create_date = self.get_now_datetime()
+                surplus_queue.expire_date = TimeHelper.add_hours_by_format_time(hour=1)
+                surplus_queue.ProcessType = 2
+                surplus_queue_model.add_entity(surplus_queue)
+
+                prize_dict = {}
+                prize_dict["serial_no"] = serial_no
+                result_list.append(prize_dict)
+                redis_prize_dict[str(serial_no)] = act_prize.id
+        self.lpop(queue_name)
+        if is_lock:
+            self.release_lock(queue_name, identifier)
+        if len(result_list) <= 0:
+            return self.reponse_json_error("NoPrize", "对不起，该盲盒已售罄")
+        result_info["key_id"] = key_id
+        result_info["specs_type"] = specs_type
+        result_info["min_machine_list"] = result_list
+
+        self.redis_init().set(f"minbox_list_{str(open_id)}_{str(key_id)}", self.json_dumps(redis_prize_dict), ex=3600 * 1)
+
         return self.reponse_json_success(result_info)
\ No newline at end of file
