@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-@LastEditTime: 2021-09-13 18:49:27
+@LastEditTime: 2021-09-14 17:09:17
 @LastEditors: HuangJianYi
 :description: 用户处理
 """
@@ -550,11 +550,10 @@ class PropLogListHandler(SevenBaseHandler):
         if end_date:
             condition += " AND create_date<=%s"
             params.append(end_date)
-        if change_type > 0:
-            if change_type == 4:
-                condition += " AND change_type in(4,5,6)"
-            else:
-                condition += " AND change_type=%s"
+        if change_type == 4:
+            condition += " AND change_type in(4,5,6)"
+        else:
+            condition += " AND change_type=%s"
             params.append(change_type)
 
         page_list, total = PropLogModel(context=self).get_dict_page_list(field, page_index, page_size, condition, order_by="id desc", params=params)
@@ -626,21 +625,21 @@ class GivePropHandler(SevenBaseHandler):
             if user_detail.tips_card_count <= 0:
                 return self.reponse_json_error("Error", "提示卡数量不足")
             if prop_give_total >= exchange_info.day_limit and exchange_info.day_limit >0:
-                return self.reponse_json_error("Error", "提示卡赠送数量达到上限")
+                return self.reponse_json_error("Error", "提示卡赠送数量已达到今日上限")
             history_value = user_detail.tips_card_count
             update_sql = "tips_card_count=tips_card_count-1"
         elif prop_type == 4:
             if user_detail.redraw_card_count <= 0:
                 return self.reponse_json_error("Error", "重抽卡数量不足")
-            if prop_give_total >= exchange_info.day_limit:
-                return self.reponse_json_error("Error", "重抽卡赠送数量达到上限")
+            if prop_give_total >= exchange_info.day_limit and exchange_info.day_limit >0:
+                return self.reponse_json_error("Error", "重抽卡赠送数量已达到今日上限")
             history_value = user_detail.redraw_card_count
             update_sql = "redraw_card_count=redraw_card_count-1"
         else:
             if user_detail.perspective_card_count <= 0:
                 return self.reponse_json_error("Error", "透视卡数量不足")
-            if prop_give_total >= exchange_info.day_limit:
-                return self.reponse_json_error("Error", "透视卡赠送数量达到上限")
+            if prop_give_total >= exchange_info.day_limit and exchange_info.day_limit >0:
+                return self.reponse_json_error("Error", "透视卡赠送数量已达到今日上限")
             history_value = user_detail.perspective_card_count
             update_sql = "perspective_card_count=perspective_card_count-1"
 
@@ -764,7 +763,7 @@ class GetPropGiveHandler(SevenBaseHandler):
         prop_log.act_id = act_id
         prop_log.open_id = open_id
         prop_log.user_nick = user_info.user_nick
-        prop_log.change_type = 5
+        prop_log.change_type = 6
         prop_log.operate_type = 0
         prop_log.prop_type = prop_give.prop_type
         prop_log.operate_value = 1
