@@ -2,8 +2,8 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-29 09:40:42
-@LastEditTime: 2021-06-21 15:53:38
-@LastEditors: WangQiang
+@LastEditTime: 2021-09-30 16:21:51
+@LastEditors: HuangJianYi
 :description: 机台（盒子）
 """
 from seven_cloudapp.handlers.seven_base import *
@@ -46,6 +46,7 @@ class MachineHandler(SevenBaseHandler):
         series_id = int(self.get_param("series_id", 0))
         specs_type = int(self.get_param("specs_type", 0))
         index_pic = self.get_param("index_pic")
+        machine_bg_pic = self.get_param("machine_bg_pic")
         goods_detail = self.get_param("goods_detail")
         box_style_type = int(self.get_param("box_style_type", 0))
         box_style_detail = self.get_param("box_style_detail")
@@ -87,6 +88,7 @@ class MachineHandler(SevenBaseHandler):
         machine_info.series_id = series_id
         machine_info.specs_type = specs_type
         machine_info.index_pic = index_pic
+        machine_info.machine_bg_pic = machine_bg_pic
         machine_info.goods_detail = goods_detail if goods_detail != "" else self.json_dumps([])
         machine_info.box_style_type = box_style_type
         machine_info.box_style_detail = box_style_detail if box_style_detail != "" else self.json_dumps({})
