@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2021-09-08 18:45:17
+@LastEditTime: 2021-12-09 10:33:38
 @LastEditors: HuangJianYi
 :Description: 潮玩盲盒基础路由
 """
@@ -113,13 +113,17 @@ def seven_cloudapp_ppmt_route():
         (r"/client/act_info", act.ActInfoHandler),
         (r"/client/machine_list", act.MachineListHandler),
         (r"/client/prize_list", act.PrizeListHandler),
+        (r"/client/minbox_list", act.MinboxListHandler),
         (r"/client/theme_info", theme.ThemeInfoHandler),
         (r"/client/theme", theme.ThemeSaveHandler),
         (r"/client/skin", theme.SkinSaveHandler),
         (r"/client/lottery", lottery.LotteryHandler),
+        (r"/client/new_lottery", lottery.NewLotteryHandler),
         (r"/client/shakeit", lottery.ShakeItHandler),
+        (r"/client/new_shakeit", lottery.NewShakeItHandler),
         (r"/client/recover", lottery.RecoverHandler),
         (r"/client/shakeit_prize_list", lottery.ShakeItPrizeListHandler),
+        (r"/client/new_shakeit_prize_list", lottery.NewShakeItPrizeListHandler),
         (r"/client/all_prize_list", prize.AllPrizeListHandler),
         (r"/client/user_prize_list", prize.UserPrizeListHandler),
         (r"/client/address", address.GetAddressInfoHandler),
